write_metadata_section

Function write_metadata_section 

pub fn write_metadata_section(
    path: &Path,
    section: MetadataSection,
    config: &InitConfig,
) -> Result<(), ManifestError>
Writes changeset configuration to the metadata section of a Cargo.toml file.

Errors

Returns an error if the manifest cannot be read, parsed, or written.