pub fn read_external_version_string(
path: &Path,
format: ManifestFormat,
version_field_path: &str,
) -> Result<String, ManifestError>Expand description
Errors
Returns an error if the manifest cannot be read or the version field path does not resolve to a string value.